@@ -697,26 +697,36 @@ int dm_stats_set_program_id(struct dm_stats *dms, int allow_empty,
  *
  * All values are returned in units of 512b sectors.
  */
-uint64_t dm_stats_get_region_start(const struct dm_stats *dms, uint64_t *start,
-				   uint64_t region_id);
-uint64_t dm_stats_get_region_len(const struct dm_stats *dms, uint64_t *len,
-				 uint64_t region_id);
-uint64_t dm_stats_get_region_area_len(const struct dm_stats *dms,
-				      uint64_t *area_len, uint64_t region_id);
+int dm_stats_get_region_start(const struct dm_stats *dms, uint64_t *start,
+			      uint64_t region_id);
+
+int dm_stats_get_region_len(const struct dm_stats *dms, uint64_t *len,
+			    uint64_t region_id);
+
+int dm_stats_get_region_area_len(const struct dm_stats *dms,
+				 uint64_t *len, uint64_t region_id);
 
 /*
- * Area properties: start and length.
+ * Area properties: start, offset and length.
  *
  * The area length is always equal to the area length of the region
  * that contains it and is obtained from dm_stats_get_region_area_len().
  *
- * The start offset of an area is a function of the area_id and the
- * containing region's start and area length.
+ * The start of an area is a function of the area_id and the containing
+ * region's start and area length: it gives the absolute offset into the
+ * containing device of the beginning of the area.
+ *
+ * The offset expresses the area's relative offset into the current
+ * region. I.e. the area start minus the start offset of the containing
+ * region.
  *
  * All values are returned in units of 512b sectors.
  */
-uint64_t dm_stats_get_area_start(const struct dm_stats *dms, uint64_t *start,
-				 uint64_t region_id, uint64_t area_id);
+int dm_stats_get_area_start(const struct dm_stats *dms, uint64_t *start,
+			    uint64_t region_id, uint64_t area_id);
+
+int dm_stats_get_area_offset(const struct dm_stats *dms, uint64_t *offset,
+			     uint64_t region_id, uint64_t area_id);
 
 /*
  * Retrieve program_id and aux_data for a specific region. Only valid
@@ -856,14 +866,14 @@ uint64_t dm_stats_get_current_area(const struct dm_stats *dms);
  *
  * All values are returned in units of 512b sectors.
  */
-uint64_t dm_stats_get_current_region_start(const struct dm_stats *dms,
-					   uint64_t *start);
+int dm_stats_get_current_region_start(const struct dm_stats *dms,
+				      uint64_t *start);
 
-uint64_t dm_stats_get_current_region_len(const struct dm_stats *dms,
-					 uint64_t *len);
+int dm_stats_get_current_region_len(const struct dm_stats *dms,
+				    uint64_t *len);
 
-uint64_t dm_stats_get_current_region_area_len(const struct dm_stats *dms,
-					      uint64_t *area_len);
+int dm_stats_get_current_region_area_len(const struct dm_stats *dms,
+					 uint64_t *area_len);
 
 /*
  * Current area properties: start and length.
@@ -873,10 +883,13 @@ uint64_t dm_stats_get_current_region_area_len(const struct dm_stats *dms,
  *
  * All values are returned in units of 512b sectors.
  */
-uint64_t dm_stats_get_current_area_start(const struct dm_stats *dms,
-					 uint64_t *start);
+int dm_stats_get_current_area_start(const struct dm_stats *dms,
+				    uint64_t *start);
 
-uint64_t dm_stats_get_current_area_len(const struct dm_stats *dms,
+int dm_stats_get_current_area_offset(const struct dm_stats *dms,
+				     uint64_t *offset);
+
+int dm_stats_get_current_area_len(const struct dm_stats *dms,
 				       uint64_t *start);
 
 /*
@@ -1308,7 +1321,7 @@ int dm_tree_node_add_cache_target(struct dm_tree_node *node,
 				  const char *origin_uuid,
 				  const char *policy_name,
 				  const struct dm_config_node *policy_settings,
-				  uint32_t chunk_size);
+				  uint32_t data_block_size);
 
 /*
  * FIXME Add individual cache policy pairs  <key> = value, like:
@@ -2182,6 +2195,11 @@ struct dm_timestamp *dm_timestamp_alloc(void);
  */
 int dm_timestamp_get(struct dm_timestamp *ts);
 
+/*
+ * Copy a timestamp from ts_old to ts_new.
+ */
+void dm_timestamp_copy(struct dm_timestamp *ts_new, struct dm_timestamp *ts_old);
+
 /*
  * Compare two timestamps.
  *
@@ -2391,6 +2409,11 @@ int dm_report_object_is_selected(struct dm_report *rh, void *object, int do_outp
  */
 int dm_report_compact_fields(struct dm_report *rh);
 
+/*
+ * Returns 1 if there is no data waiting to be output.
+ */
+int dm_report_is_empty(struct dm_report *rh);
+
 int dm_report_output(struct dm_report *rh);
 
 /*
