@@ -79,11 +79,15 @@ static char *_program_id_from_proc(void)
 	if (!(comm = fopen(PROC_SELF_COMM, "r")))
 		return_NULL;
 
-	if (!fgets(buf, sizeof(buf), comm))
-		return_NULL;
+	if (!fgets(buf, sizeof(buf), comm)) {
+		log_error("Could not read from %s", PROC_SELF_COMM);
+		if(fclose(comm))
+			stack;
+		return NULL;
+	}
 
 	if (fclose(comm))
-		return_NULL;
+		stack;
 
 	return dm_strdup(buf);
 }
@@ -92,10 +96,10 @@ struct dm_stats *dm_stats_create(const char *program_id)
 {
 	struct dm_stats *dms = NULL;
 
-	if (!(dms = dm_malloc(sizeof(*dms))))
+	if (!(dms = dm_zalloc(sizeof(*dms))))
 		return_NULL;
 	if (!(dms->mem = dm_pool_create("stats_pool", 4096)))
-		return_NULL;
+		goto_out;
 
 	if (!program_id || !strlen(program_id))
 		dms->program_id = _program_id_from_proc();
@@ -115,6 +119,9 @@ struct dm_stats *dm_stats_create(const char *program_id)
 	dms->regions = NULL;
 
 	return dms;
+out:
+	dm_free(dms);
+	return NULL;
 }
 
 /**
@@ -335,10 +342,13 @@ static int _stats_parse_list(struct dm_stats *dms, const char *resp)
 	dms->max_region = max_region - 1;
 	dms->regions = dm_pool_end_object(mem);
 
-	fclose(list_rows);
+	if (fclose(list_rows))
+		stack;
+
 	return 1;
 out:
-	fclose(list_rows);
+	if(fclose(list_rows))
+		stack;
 	dm_pool_abandon_object(mem);
 	return 0;
 }
@@ -478,13 +488,16 @@ static int _stats_parse_region(struct dm_pool *mem, const char *resp,
 	region->timescale = timescale;
 	region->counters = dm_pool_end_object(mem);
 
-	fclose(stats_rows);
+	if (fclose(stats_rows))
+		stack;
+
 	return 1;
 
 out:
 
 	if (stats_rows)
-		fclose(stats_rows);
+		if(fclose(stats_rows))
+			stack;
 	dm_pool_abandon_object(mem);
 	return 0;
 }
@@ -498,8 +511,7 @@ static uint64_t _nr_areas(uint64_t len, uint64_t step)
 	 * treat the entire region as a single area. Any partial area at the
 	 * end of the region is treated as an additional complete area.
 	 */
-	return (len && step)
-		? (len / (step ? step : len)) + !!(len % step) : 0;
+	return (len / (step ? : len)) + !!(len % step);
 }
 
 static uint64_t _nr_areas_region(struct dm_stats_region *region)
@@ -1268,7 +1280,7 @@ uint64_t dm_stats_get_current_area(const struct dm_stats *dms)
 	return dms->cur_area;
 }
 
-uint64_t dm_stats_get_region_start(const struct dm_stats *dms, uint64_t *start,
+int dm_stats_get_region_start(const struct dm_stats *dms, uint64_t *start,
 			      uint64_t region_id)
 {
 	if (!dms || !dms->regions)
@@ -1277,7 +1289,7 @@ uint64_t dm_stats_get_region_start(const struct dm_stats *dms, uint64_t *start,
 	return 1;
 }
 
-uint64_t dm_stats_get_region_len(const struct dm_stats *dms, uint64_t *len,
+int dm_stats_get_region_len(const struct dm_stats *dms, uint64_t *len,
 			    uint64_t region_id)
 {
 	if (!dms || !dms->regions)
@@ -1286,51 +1298,68 @@ uint64_t dm_stats_get_region_len(const struct dm_stats *dms, uint64_t *len,
 	return 1;
 }
 
-uint64_t dm_stats_get_region_area_len(const struct dm_stats *dms, uint64_t *step,
-			    uint64_t region_id)
+int dm_stats_get_region_area_len(const struct dm_stats *dms, uint64_t *len,
+				 uint64_t region_id)
 {
 	if (!dms || !dms->regions)
 		return_0;
-	*step = dms->regions[region_id].step;
+	*len = dms->regions[region_id].step;
 	return 1;
 }
 
-uint64_t dm_stats_get_current_region_start(const struct dm_stats *dms,
-					   uint64_t *start)
+int dm_stats_get_current_region_start(const struct dm_stats *dms,
+				      uint64_t *start)
 {
 	return dm_stats_get_region_start(dms, start, dms->cur_region);
 }
 
-uint64_t dm_stats_get_current_region_len(const struct dm_stats *dms,
-					 uint64_t *len)
+int dm_stats_get_current_region_len(const struct dm_stats *dms,
+				    uint64_t *len)
 {
 	return dm_stats_get_region_len(dms, len, dms->cur_region);
 }
 
-uint64_t dm_stats_get_current_region_area_len(const struct dm_stats *dms,
-					      uint64_t *step)
+int dm_stats_get_current_region_area_len(const struct dm_stats *dms,
+					 uint64_t *step)
 {
 	return dm_stats_get_region_area_len(dms, step, dms->cur_region);
 }
 
-uint64_t dm_stats_get_area_start(const struct dm_stats *dms, uint64_t *start,
-				 uint64_t region_id, uint64_t area_id)
+int dm_stats_get_area_start(const struct dm_stats *dms, uint64_t *start,
+			    uint64_t region_id, uint64_t area_id)
 {
+	struct dm_stats_region *region = &dms->regions[region_id];
 	if (!dms || !dms->regions)
 		return_0;
-	*start = dms->regions[region_id].step * area_id;
+	*start = region->start + region->step * area_id;
 	return 1;
 }
 
-uint64_t dm_stats_get_current_area_start(const struct dm_stats *dms,
-					 uint64_t *start)
+int dm_stats_get_area_offset(const struct dm_stats *dms, uint64_t *offset,
+			     uint64_t region_id, uint64_t area_id)
+{
+	if (!dms || !dms->regions)
+		return_0;
+	*offset = dms->regions[region_id].step * area_id;
+	return 1;
+}
+
+int dm_stats_get_current_area_start(const struct dm_stats *dms,
+				    uint64_t *start)
 {
 	return dm_stats_get_area_start(dms, start,
 				       dms->cur_region, dms->cur_area);
 }
 
-uint64_t dm_stats_get_current_area_len(const struct dm_stats *dms,
-				       uint64_t *len)
+int dm_stats_get_current_area_offset(const struct dm_stats *dms,
+					  uint64_t *offset)
+{
+	return dm_stats_get_area_offset(dms, offset,
+				       dms->cur_region, dms->cur_area);
+}
+
+int dm_stats_get_current_area_len(const struct dm_stats *dms,
+				  uint64_t *len)
 {
 	return dm_stats_get_region_area_len(dms, len, dms->cur_region);
 }
