@@ -33,7 +33,7 @@ void *cmdlib_lvm2_init(unsigned static_compile)
 	lvm_register_commands();
 
 	init_is_static(static_compile);
-	if (!(cmd = init_lvm()))
+	if (!(cmd = init_lvm(1, 1)))
 		return NULL;
 
 	return (void *) cmd;
